/*******************************************************************************
 * Copyright (c) 2009 Martin O. J. Schmitz.
 * 
 * This file is part of the SCHMITZM library - a collection of utility 
 * classes based on Java 1.6, focusing (not only) on Java Swing 
 * and the Geotools library.
 * 
 * The SCHMITZM project is hosted at:
 * http://wald.intevation.org/projects/schmitzm/
 * 
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * as published by the Free Software Foundation; either version 3
 * of the License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License (license.txt)
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 * or try this link: http://www.gnu.org/licenses/lgpl.html
 * 
 * Contributors:
 *     Martin O. J. Schmitz - initial API and implementation
 *     Stefan A. Tzeggai - additional utility classes
 ******************************************************************************/
package de.schmitzm.jfree.feature;

import org.geotools.feature.FeatureCollection;
import org.jfree.data.general.PieDataset;
import org.opengis.feature.simple.SimpleFeature;

/**
 * This class implements the mapping between {@link PieDataset} items (pie pieces in chart)
 * and the corresponding {@link SimpleFeature Features}.
 * The structure of this mapping assumes that is only one dataset item
 * for one feature and only one feature for each dataset item.
 * @author <a href="mailto:martin.schmitz@koeln.de">Martin Schmitz</a>
 */
public class Feature2PieDatasetMapping extends Feature2DatasetMapping<PieDataset,Comparable<?>,Comparable<?>> {
  /**
   * Creates a mapping. 
   * @param fc a {@link FeatureCollection} (can be {@code null})
   * @param dataset a {@link PieDataset} 
   */
  public Feature2PieDatasetMapping(FeatureCollection fc, PieDataset dataset) {
    super(fc, dataset);
  }

  /**
   * Returns an empty string because a {@link PieDataset} has only one
   * series and there is nothing like "series key" for this.
   */
  public Comparable<?> getPrimarySeriesKey() {
    return "";
  }
  
}
