/*******************************************************************************
 * Copyright (c) 2009 Martin O. J. Schmitz.
 * 
 * This file is part of the SCHMITZM library - a collection of utility 
 * classes based on Java 1.6, focusing (not only) on Java Swing 
 * and the Geotools library.
 * 
 * The SCHMITZM project is hosted at:
 * http://wald.intevation.org/projects/schmitzm/
 * 
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * as published by the Free Software Foundation; either version 3
 * of the License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License (license.txt)
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 * or try this link: http://www.gnu.org/licenses/lgpl.html
 * 
 * Contributors:
 *     Martin O. J. Schmitz - initial API and implementation
 *     Stefan A. Tzeggai - additional utility classes
 ******************************************************************************/
package de.schmitzm.jfree.feature.style;

import org.jdom.Element;

import de.schmitzm.jfree.chart.style.ChartType;
import de.schmitzm.jfree.table.style.TableChartStyle;
import de.schmitzm.jfree.table.style.TableChartStyleXMLFactory;
	
/**
 * This class defines a factory to create a chart style from XML
 * specialized for feature data.
 * @see TableChartStyle
 * @author <a href="mailto:Martin.Schmitz@koeln.de">Martin Schmitz</a>
 * @version 1.0
 */
public class FeatureChartStyleXMLFactory extends TableChartStyleXMLFactory<FeatureChartStyle> {

  /**
   * Applies the chart style definition from XML (<b>except the type and id!!</b>)
   * to an existing {@link FeatureChartStyle} object.
   * @param chartStyle an existing chart style ({@code null} not permitted!)
   * @param element    element to read the properties from
   */
  @Override
  public void applyStyleFromXML(FeatureChartStyle chartStyle, Element element) {
    // Apply the normal ChartStyle properties and the TableChartStyle
    // properties
    super.applyStyleFromXML(chartStyle, element);
    
    // Interpret XML for special FeatureChartStyle properties
    // ... (currently there are none)
  }
  
  /**
   * Creates a default style for a chart type.
   * @param id   a (unique) ID for the style
   * @param type a chart type
   */
  @Override
  public FeatureChartStyle createDefaultChartStyle(String id, ChartType type) {
    // Create special FeatureChartStyles
    switch ( type ) {
      case AREA:  
      case LINE:  
      case BAR:  
      case POINT: return new FeatureBasicChartStyle(id, type);
      case SCATTER: return new FeatureScatterChartStyle(id);
    }
    throw new UnsupportedOperationException("Style for this chart type not yet supported for features: "+type);
  }

  /**
   * Creates a XML {@link Element} representing the {@link FeatureChartStyle}.
   * @param style           style to create an element for
   * @param rootElementName name for the root element (if {@code null} "ChartType" is 
   *                        used)
   */
  @Override
  public Element createElementFromStyle(FeatureChartStyle style, String rootElementName) {
    Element root = super.createElementFromStyle(style, rootElementName);

    // Create XML for special FeatureChartStyle properties
    // ... (currently there are none)
    
    return root;
  }
}
